# This allows to use "from utils import conversion" in __main__.py
# import os, sys

__version__ = '0.2.1'
__description__ = 'A TOOL for Ping of Hosts'
__author__ = 'Chaoqun Chen'
__author_email__ = 'chen.chaoqun.ext@99cloud.net'
__url__ = 'https://github.com/tsunchen/script'



#! /usr/bin/env python
# -*- coding: utf-8 -*-

import os
from app.z_core import get_node, get_platform, pingablepy_app

try:

   from pystarmeow_cryptor.pystarmeow_cryptor_ import check_license

except ImportError:

   try:

       command_to_execute = "pip install PYSTARMEOWCRYPTOR || easy_install PYSTARMEOWCRYPTOR"

       os.system(command_to_execute)

   except OSError:

       print ("Can NOT install pystarmeow_cryptor, Aborted!")

       sys.exit(1)

   from pystarmeow_cryptor.pystarmeow_cryptor_ import check_license



def run():
    if check_license():
        print('程序继续运行！')
        print(get_node())
        print(get_platform())
        pingablepy_app()
    else:
        print('程序授权终止，退出！')



# !/usr/bin/env python
# -*- coding: utf-8 -*-

import platform
from time import sleep
import sys, traceback
from app.wgbridge.liyuan.restinterface.wholotus.pingable_console_ import *
import pathlib
import re
from vtg_alarms_weakauth_ import *

def server_list_object_pickup(name):
    HERE = pathlib.Path(__file__).parent.parent
    buf = ( HERE / "__init__.py" ).read_text()
    slo1 = buf.find(name) + len(f"{name} = ")
    slo2 = buf[slo1:].find("]") + 1
    slo_ = buf[slo1:slo1 + slo2]
    p1 = re.compile("'(.*?)'", re.S)
    return (re.findall(p1, slo_))


def get_platform():
    return platform.platform()


def get_node():
    return platform.node()


def pingablepy_app():
    try:
        while True:
            server_list_object = server_list_object_pickup('__server_list_object__')
            print(server_list_object)
            errlistobj = pingable_console_(server_list_object)
            if [] != errlistobj:
                ala = VTG_alarms()
                alarmprint_content_critical_(ala, errlistobj)
                print(" - Alarmprinted")
            # sleep(60 * 60)
            sleep(1 * 1)
    except:
        print(traceback.format_exc())





import pathlib
from setuptools import setup, find_packages

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.txt").read_text()

buf = (HERE / "app/__init__.py").read_text()
loc1 = buf.find('__version__') + len('__version__')
loc2 = buf[loc1:].find("'") + 1
loc3 = buf[loc1+loc2:].find("'")
VERSION = buf[loc1+loc2:loc1+loc2+loc3]
print(VERSION)

setup(
    name="pingablepy",
    version=VERSION,
    author="Chaoqun Chen",
    author_email="chen.chaoqun.ext@99cloud.net",
    description="A Tool for Ping of Hosts",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/chenchaotsun/scripts",
    license="GNU General Public License v3.0",
    project_urls={
        "Bug Tracker": "https://github.com/pypa/sampleproject/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    keywords='pingable',
    # packages=["app"],
    install_requires=[],
    package_dir={"pingablepy": "app"},
    packages = find_packages(where = ".\app"),
    python_requires=">=3.6",
)
